aboutsummaryrefslogtreecommitdiff
path: root/test/MC/AMDGPU/hsa.s
diff options
context:
space:
mode:
Diffstat (limited to 'test/MC/AMDGPU/hsa.s')
-rw-r--r--test/MC/AMDGPU/hsa.s34
1 files changed, 14 insertions, 20 deletions
diff --git a/test/MC/AMDGPU/hsa.s b/test/MC/AMDGPU/hsa.s
index b428c817ea67..5f1297e0f376 100644
--- a/test/MC/AMDGPU/hsa.s
+++ b/test/MC/AMDGPU/hsa.s
@@ -37,25 +37,19 @@
.hsa_code_object_isa 7,0,0,"AMD","AMDGPU"
// ASM: .hsa_code_object_isa 7,0,0,"AMD","AMDGPU"
-.amdgpu_runtime_metadata
- {
- amd.MDVersion: [ 2, 0 ]
- amd.Kernels: [
- { amd.KernelName: amd_kernel_code_t_test_all },
- { amd.KernelName: amd_kernel_code_t_minimal }
- ]
- }
-.end_amdgpu_runtime_metadata
+.amdgpu_code_object_metadata
+ Version: [ 3, 0 ]
+ Kernels:
+ - Name: amd_kernel_code_t_test_all
+ - Name: amd_kernel_code_t_minimal
+.end_amdgpu_code_object_metadata
-// ASM: .amdgpu_runtime_metadata
-// ASM: {
-// ASM: amd.MDVersion: [ 2, 0 ]
-// ASM: amd.Kernels: [
-// ASM: { amd.KernelName: amd_kernel_code_t_test_all },
-// ASM: { amd.KernelName: amd_kernel_code_t_minimal }
-// ASM: ]
-// ASM: }
-// ASM: .end_amdgpu_runtime_metadata
+// ASM: .amdgpu_code_object_metadata
+// ASM: Version: [ 3, 0 ]
+// ASM: Kernels:
+// ASM: - Name: amd_kernel_code_t_test_all
+// ASM: - Name: amd_kernel_code_t_minimal
+// ASM: .end_amdgpu_code_object_metadata
.amdgpu_hsa_kernel amd_kernel_code_t_test_all
.amdgpu_hsa_kernel amd_kernel_code_t_minimal
@@ -214,7 +208,7 @@ amd_kernel_code_t_minimal:
// ASM-LABEL: {{^}}amd_kernel_code_t_minimal:
// ASM: .amd_kernel_code_t
// ASM: amd_code_version_major = 1
-// ASM: amd_code_version_minor = 0
+// ASM: amd_code_version_minor = 1
// ASM: amd_machine_kind = 1
// ASM: amd_machine_version_major = 7
// ASM: amd_machine_version_minor = 0
@@ -273,6 +267,6 @@ amd_kernel_code_t_minimal:
// ASM: group_segment_alignment = 4
// ASM: private_segment_alignment = 4
// ASM: wavefront_size = 6
-// ASM: call_convention = 0
+// ASM: call_convention = -1
// ASM: runtime_loader_kernel_symbol = 0
// ASM: .end_amd_kernel_code_t